// @flow
import {
  NativeModules,
} from 'react-native';
import { vsprintf } from 'sprintf-js';

const customLogger = NativeModules.CustomLogger;
if (!customLogger) {
  console.error('not found customLogger');
}

const loggerWrapper = {};
const logFactory = methodName => function (...params: Array<any>) {
  const method = customLogger[methodName];
  if (params && params.length) {
    const fmt = params.shift();
    method.apply(method, [vsprintf(fmt, params)]);
  }
};

loggerWrapper.info = logFactory('info');
loggerWrapper.debug = logFactory('debug');
loggerWrapper.warn = logFactory('warn');
loggerWrapper.error = logFactory('error');
loggerWrapper.retrieveLogFiles = customLogger.retrieveLogFiles;

export default loggerWrapper;
