//
//  ZKLumerjackLogger.m
//  ieltsmobile
//
//  Created by wansong.mbp.work on 07/11/2016.
//  Copyright © 2016 Facebook. All rights reserved.
//

#import "ZKLumberjackLogger.h"
#import <CocoaLumberjack/CocoaLumberjack.h>

#ifdef DEBUG
static const DDLogLevel zk_ddLogLevel = DDLogLevelVerbose;
#else
static const DDLogLevel zk_ddLogLevel = DDLogLevelInfo;
#endif
/**
 * The constant/variable/method responsible for controlling the current log level.
 **/
#ifdef LOG_LEVEL_DEF
#undef LOG_LEVEL_DEF
#endif

#define LOG_LEVEL_DEF zk_ddLogLevel

/**
 * Whether async should be used by log messages, excluding error messages that are always sent sync.
 **/
#ifdef LOG_ASYNC_ENABLED
#undef LOG_ASYNC_ENABLED
#endif

#ifdef DEBUG
#define LOG_ASYNC_ENABLED NO
#else
#define LOG_ASYNC_ENABLED YES
#endif


DDFileLogger *_fileLogger;
@implementation ZKLumberjackLogger

- (instancetype)init {
  self = [super init];
  if (self) {
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
      _fileLogger = [[DDFileLogger alloc] init];
      [DDLog addLogger:_fileLogger];
    });
#ifdef DEBUG
    [DDLog addLogger:[DDTTYLogger sharedInstance]];
#endif
  }
  return self;
}

RCT_EXPORT_MODULE(CustomLogger);

RCT_EXPORT_METHOD(info:(NSString*)message) {
  DDLogInfo(@"%@", message);
}

RCT_EXPORT_METHOD(error:(NSString*)message) {
  DDLogError(@"%@", message);
}

RCT_EXPORT_METHOD(warn:(NSString*)message) {
  DDLogWarn(@"%@", message);
}

RCT_EXPORT_METHOD(debug:(NSString*)message) {
  DDLogDebug(@"%@", message);
}

RCT_EXPORT_METHOD(retrieveLogFiles:(RCTResponseSenderBlock)callback) {
  NSArray<NSString*> *paths = [_fileLogger.logFileManager sortedLogFilePaths];
  if (callback) {
    callback(@[[NSNull null], paths]);
  }
}

@end
